@@ -1,2 +1,2 @@
-from browser import Browser
+from browser import Browser, CannedResponse
 from rest_client import RestClient, RestClientJson
